fix_format

Change-Id: I34e265de434263a11654e5deba044c3f21e86578
This commit is contained in:
Sandeep Kumar
2016-11-15 12:41:05 +05:30
committed by Maneesh Gupta
parent 8829e2626c
commit 5e86e5f565
2 changed files with 41 additions and 42 deletions
+6 -6
View File
@@ -108,7 +108,7 @@ void disablePeer2Peer(int currentGpu, int peerGpu)
HIPCHECK(hipSetDevice(currentGpu));
hipDeviceCanAccessPeer(&canAccessPeer, currentGpu, peerGpu);
if(canAccessPeer==1){
HIPCHECK(hipDeviceDisablePeerAccess(peerGpu));
}
@@ -155,7 +155,7 @@ __global__ void matrixTranspose_dynamic_shared(hipLaunchParm lp,
int main(){
checkPeer2PeerSupport();
int gpuCount;
int currentGpu, peerGpu;
@@ -191,10 +191,10 @@ int main(){
0, 0,
gpuTransposeMatrix[0], data[0], width);
HIPCHECK(hipSetDevice(peerGpu));
TransposeMatrix[1] = (float*)malloc(NUM * sizeof(float));
hipMalloc((void**)&gpuTransposeMatrix[1], NUM * sizeof(float));
hipMalloc((void**)&data[1], NUM * sizeof(float));
HIPCHECK(hipSetDevice(peerGpu));
TransposeMatrix[1] = (float*)malloc(NUM * sizeof(float));
hipMalloc((void**)&gpuTransposeMatrix[1], NUM * sizeof(float));
hipMalloc((void**)&data[1], NUM * sizeof(float));
hipMemcpy(data[1], gpuTransposeMatrix[0], NUM * sizeof(float), hipMemcpyDeviceToDevice);
hipLaunchKernel(matrixTranspose_dynamic_shared,